Module: Cuprum::Collections

Defined in:
lib/cuprum/collections.rb,
lib/cuprum/collections/basic.rb,
lib/cuprum/collections/query.rb,
lib/cuprum/collections/rspec.rb,
lib/cuprum/collections/scope.rb,
lib/cuprum/collections/errors.rb,
lib/cuprum/collections/scopes.rb,
lib/cuprum/collections/adapter.rb,
lib/cuprum/collections/queries.rb,
lib/cuprum/collections/version.rb,
lib/cuprum/collections/adapters.rb,
lib/cuprum/collections/commands.rb,
lib/cuprum/collections/relation.rb,
lib/cuprum/collections/resource.rb,
lib/cuprum/collections/adaptable.rb,
lib/cuprum/collections/relations.rb,
lib/cuprum/collections/collection.rb,
lib/cuprum/collections/repository.rb,
lib/cuprum/collections/association.rb,
lib/cuprum/collections/constraints.rb,
lib/cuprum/collections/associations.rb,
lib/cuprum/collections/collection_command.rb

Overview

A data abstraction layer based on the Cuprum library.

Defined Under Namespace

Modules: Adaptable, Adapters, Associations, Basic, Commands, Constraints, Errors, Queries, RSpec, Relations, Scopes, Version Classes: Adapter, Association, Collection, CollectionCommand, Query, Relation, Repository, Resource, Scope

Constant Summary collapse

VERSION =

Returns the current version of the gem.

Returns:

  • (String)

    the current version of the gem.

Version.to_gem_version

Class Method Summary collapse

Class Method Details

.gem_pathString

Returns the absolute path to the gem directory.

Returns:

  • (String)

    the absolute path to the gem directory.



29
30
31
32
33
34
# File 'lib/cuprum/collections.rb', line 29

def self.gem_path
  sep     = File::SEPARATOR
  pattern = /#{sep}lib#{sep}cuprum#{sep}?\z/

  __dir__.sub(pattern, '')
end

.versionString

Returns the current version of the gem.

Returns:

  • (String)

    the current version of the gem.



37
38
39
# File 'lib/cuprum/collections.rb', line 37

def self.version
  VERSION
end