Module: Cuprum::Collections::Adaptable::Commands::AbstractValidateOne

Includes:
ParameterValidation
Defined in:
lib/cuprum/collections/adaptable/commands/abstract_validate_one.rb

Overview

Abstract, adaptable implementation of the ValidateOne command.

Instance Method Summary collapse

Instance Method Details

#call(entity:, contract: nil) ⇒ Cuprum::Result<Hash>

Validates the entity against the given or default contract.

If the entity matches the contract, #call will return a passing result with the entity as the result value. If the entity does not match the contract, #call will return a failing result with a FailedValidation error and the validation errors.

Parameters:

  • contract (Stannum::Constraints:Base) (defaults to: nil)

    The contract with which to validate the entity. If not given, the entity will be validated using the collection's default contract.

  • entity (Hash)

    The collection entity to validate.

Returns:

  • (Cuprum::Result<Hash>)

    the validated entity.



26
# File 'lib/cuprum/collections/adaptable/commands/abstract_validate_one.rb', line 26

validate :contract, Stannum::Constraints::Base, optional: true