Module: Cuprum::Collections::Commands::AbstractFindMatching
- Includes:
- ParameterValidation
- Included in:
- Basic::Commands::FindMatching
- Defined in:
- lib/cuprum/collections/commands/abstract_find_matching.rb
Overview
Abstract implementation of the FindMatching command.
Instance Method Summary collapse
-
#call(envelope: false, limit: nil, offset: nil, order: nil, scope: nil, where: nil) { ... } ⇒ Object
Queries the collection for items matching the given conditions.
Instance Method Details
#call(limit: nil, offset: nil, order: nil, &block) ⇒ Cuprum::Result<Enumerator> #call(limit: nil, offset: nil, order: nil, &block) ⇒ Cuprum::Result<Hash{String, Array<Hash{String, Object}>}>
Queries the collection for items matching the given conditions.
102 |
# File 'lib/cuprum/collections/commands/abstract_find_matching.rb', line 102 validate :envelope, :boolean, optional: true |