Module: Cuprum::Collections::RSpec::Contracts::Scopes::CriteriaContracts::ShouldBeACriteriaScopeContract Deprecated
- Extended by:
- RSpec::SleepingKingStudios::Contract
- Defined in:
- lib/cuprum/collections/rspec/contracts/scopes/criteria_contracts.rb
Overview
Deprecated.
0.6.0
Contract validating the behavior of a Criteria scope implementation.
Instance Method Summary collapse
-
#apply(example_group, abstract: false, constructor: true, equality: true, ignore_uninvertible: false) ⇒ Object
Adds the contract to the example group.
Instance Method Details
#apply(example_group, abstract: false, constructor: true, equality: true, ignore_uninvertible: false) ⇒ Object
Adds the contract to the example group.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/cuprum/collections/rspec/contracts/scopes/criteria_contracts.rb', line 30 contract do | abstract: false, equality: true, constructor: true, ignore_uninvertible: false | = 'Use deferred examples "should implement the CriteriaScope methods"' SleepingKingStudios::Tools::Toolbelt .instance .core_tools .deprecate( 'ShouldBeACriteriaScopeContract', message: ) shared_context 'when initialized with inverted: true' do let(:constructor_options) { super().merge(inverted: true) } end shared_context 'with criteria' do let(:criteria) do operators = Cuprum::Collections::Queries::Operators [ ['title', operators::EQUAL, 'Gideon the Ninth'], ['author', operators::EQUAL, 'Tamsyn Muir'] ] end end let(:criteria) { [] } describe '.new' do next unless constructor it 'should define the constructor' do expect(described_class) .to be_constructible .with(0).arguments .and_keywords(:criteria, :inverted) .and_any_keywords end end describe '.build' do let(:value) { { 'title' => 'The Word for World is Forest' } } def parse_criteria(*args, &block) return described_class.build(&block).criteria if args.empty? described_class.build(args.first, &block).criteria end it 'should define class method' do expect(described_class) .to respond_to(:build) .with(0..1).arguments .and_a_block end it { expect(described_class.build(value)).to be_a described_class } include_contract 'should parse criteria' end describe '.parse' do def parse_criteria(*args, &block) return described_class.parse(&block) if args.empty? described_class.parse(args.first, &block) end it 'should define class method' do expect(described_class) .to respond_to(:parse) .with(0..1).arguments .and_a_block end include_contract 'should parse criteria' end include_contract 'should be a scope', invertible: true include_contract 'should compose scopes for criteria' describe '#==' do next unless equality describe 'with a scope with the same class' do let(:other_criteria) { [] } let(:other_inverted) { false } let(:other) do described_class.new( criteria: other_criteria, inverted: other_inverted ) end describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be true } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end wrap_context 'with criteria' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with matching criteria' do let(:other_criteria) { subject.criteria } it { expect(subject == other).to be true } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end end wrap_context 'when initialized with inverted: true' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be true } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end wrap_context 'with criteria' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with matching criteria' do let(:other_criteria) { subject.criteria } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be true } end end end end end describe 'with a scope with the same type' do let(:other_criteria) { [] } let(:other_inverted) { false } let(:other) do described_class.new( criteria: other_criteria, inverted: other_inverted ) end example_class 'Spec::CustomScope', Cuprum::Collections::Scopes::Base \ do |klass| klass.include Cuprum::Collections::Scopes::Criteria end describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be true } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end wrap_context 'with criteria' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with matching criteria' do let(:other_criteria) { subject.criteria } it { expect(subject == other).to be true } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end end wrap_context 'when initialized with inverted: true' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be true } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end wrap_context 'with criteria' do describe 'with empty criteria' do let(:other_criteria) { [] } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with non-matching criteria' do let(:other_criteria) do operators = Cuprum::Collections::Queries::Operators [ [ 'ok', operators::EQUAL, true ] ] end it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be false } end end describe 'with matching criteria' do let(:other_criteria) { subject.criteria } it { expect(subject == other).to be false } describe 'with inverted: true' do let(:other_inverted) { true } it { expect(subject == other).to be true } end end end end end end describe '#as_json' do let(:expected) do { 'criteria' => subject.criteria, 'inverted' => subject.inverted?, 'type' => subject.type } end it { expect(subject.as_json).to be == expected } wrap_context 'when initialized with inverted: true' do it { expect(subject.as_json).to be == expected } end wrap_context 'with criteria' do it { expect(subject.as_json).to be == expected } wrap_context 'when initialized with inverted: true' do it { expect(subject.as_json).to be == expected } end end end describe '#call' do next if abstract it { expect(subject).to respond_to(:call) } include_contract 'should filter data by criteria' context 'when the scope is inverted' do subject { super().invert } let(:matching_data) { data - filtered_data } include_contract 'should filter data by criteria', ignore_invalid: true, inverted: true end end describe '#criteria' do include_examples 'should define reader', :criteria, -> { criteria } wrap_context 'with criteria' do it { expect(subject.criteria).to be == criteria } end end describe '#empty?' do include_examples 'should define predicate', :empty?, true wrap_context 'with criteria' do it { expect(subject.empty?).to be false } end end describe '#invert' do shared_examples 'should invert the criteria' do it { expect(copy.criteria).to be == [] } context 'when the scope has an equality criterion' do let(:criteria) do described_class.parse({ 'title' => 'The Word for World is Forest' }) end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'title', operators::NOT_EQUAL, 'The Word for World is Forest' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a greater than criterion' do let(:criteria) do described_class.parse do |scope| { 'published_at' => scope.greater_than('1972-03-13') } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'published_at', operators::LESS_THAN_OR_EQUAL_TO, '1972-03-13' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a greater than or equal to criterion' do let(:criteria) do described_class.parse do |scope| { 'published_at' => scope.greater_than_or_equal_to( '1972-03-13' ) } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'published_at', operators::LESS_THAN, '1972-03-13' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a less than criterion' do let(:criteria) do described_class.parse do |scope| { 'published_at' => scope.less_than('1972-03-13') } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'published_at', operators::GREATER_THAN_OR_EQUAL_TO, '1972-03-13' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a less than or equal to criterion' do let(:criteria) do described_class.parse do |scope| { 'published_at' => scope.less_than_or_equal_to( '1972-03-13' ) } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'published_at', operators::GREATER_THAN, '1972-03-13' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a not equal criterion' do let(:criteria) do described_class.parse do |scope| { 'author' => scope.not_equal('J.R.R. Tolkien') } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'author', operators::EQUAL, 'J.R.R. Tolkien' ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a not one of criterion' do let(:criteria) do described_class.parse do |scope| titles = ['The Fellowship Of The Ring', 'The Two Towers'] { 'title' => scope.not_one_of(titles) } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'title', operators::ONE_OF, ['The Fellowship Of The Ring', 'The Two Towers'] ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has a one of criterion' do let(:criteria) do described_class.parse do |scope| titles = ['The Fellowship Of The Ring', 'The Two Towers'] { 'title' => scope.one_of(titles) } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'title', operators::NOT_ONE_OF, ['The Fellowship Of The Ring', 'The Two Towers'] ] ] end it { expect(copy.criteria).to be == expected } end context 'when the scope has multiple criteria' do let(:criteria) do described_class.parse do |scope| titles = ['The Fellowship Of The Ring', 'The Two Towers'] { 'author' => 'J.R.R. Tolkien', 'title' => scope.not_one_of(titles) } end end let(:expected) do operators = Cuprum::Collections::Queries::Operators [ [ 'author', operators::NOT_EQUAL, 'J.R.R. Tolkien' ], [ 'title', operators::ONE_OF, ['The Fellowship Of The Ring', 'The Two Towers'] ] ] end it { expect(copy.criteria).to be == expected } end context 'when initialized with uninvertible criteria' do next if ignore_uninvertible let(:criteria) do [ [ 'title', 'random', nil ] ] end let(:error_class) do Cuprum::Collections::Queries::UninvertibleOperatorException end let(:error_message) { 'uninvertible operator "random"' } it 'should raise an exception' do expect { subject.invert } .to raise_error error_class, end end end let(:copy) { subject.invert } it { expect(copy).to be_a described_class } it { expect(copy.inverted?).to be true } include_examples 'should invert the criteria' wrap_context 'when initialized with inverted: true' do it { expect(copy).to be_a described_class } it { expect(copy.inverted?).to be false } include_examples 'should invert the criteria' end end describe '#inverted?' do include_examples 'should define predicate', :inverted?, false wrap_context 'when initialized with inverted: true' do it { expect(subject.inverted?).to be true } end end describe '#type' do include_examples 'should define reader', :type, :criteria end describe '#with_criteria' do let(:new_criteria) { ['author', 'eq', 'Ursula K. LeGuin'] } it { expect(subject).to respond_to(:with_criteria).with(1).argument } it 'should return a scope' do expect(subject.with_criteria(new_criteria)).to be_a described_class end it "should not change the original scope's criteria" do expect { subject.with_criteria(new_criteria) } .not_to change(subject, :criteria) end it "should set the copied scope's criteria" do expect(subject.with_criteria(new_criteria).criteria) .to be == new_criteria end it 'should return an uninverted scope' do expect(subject.with_criteria(new_criteria).inverted?).to be false end wrap_context 'with criteria' do it "should not change the original scope's criteria" do expect { subject.with_criteria(new_criteria) } .not_to change(subject, :criteria) end it "should set the copied scope's criteria" do expect(subject.with_criteria(new_criteria).criteria) .to be == new_criteria end end wrap_context 'when initialized with inverted: true' do it 'should return an inverted scope' do expect(subject.with_criteria(new_criteria).inverted?).to be true end end end end |